'use strict';

exports.__esModule = true;
exports.showDate = showDate;
exports['default'] = ShowField;

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _numeral = require('numeral');

var _numeral2 = _interopRequireDefault(_numeral);

var _DescriptionList = require('ant-design-pro/lib/DescriptionList');

var _DescriptionList2 = _interopRequireDefault(_DescriptionList);

var _InputStyle = require('./Constants/InputStyle');

var _InputStyle2 = _interopRequireDefault(_InputStyle);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var Description = _DescriptionList2['default'].Description;


function monthAbbreviation(x) {
  switch (x) {
    case 0:
      return 'Jan';
    case 1:
      return 'Feb';
    case 2:
      return 'Mar';
    case 3:
      return 'Apr';
    case 4:
      return 'May';
    case 5:
      return 'Jun';
    case 6:
      return 'Jul';
    case 7:
      return 'Aug';
    case 8:
      return 'Sep';
    case 9:
      return 'Oct';
    case 10:
      return 'Nov';
    case 11:
      return 'Dec';
    default:
      return '';
  }
}

function showDate(date) {
  if (!date) return '';
  var dateAt = new Date(date);
  return monthAbbreviation(dateAt.getMonth()) + ' ' + dateAt.getDate() + ', ' + dateAt.getFullYear();
}

function ShowField(field, data) {
  var showProps = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  var showExtra = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;

  switch (field.InputStyle) {
    case _InputStyle2['default'].Input:
      return data[field.Column] ? _react2['default'].createElement(
        Description,
        { key: field.Id, term: field.Label },
        data[field.Column]
      ) : null;
    case _InputStyle2['default'].InputNumber:
      return data[field.Column] ? _react2['default'].createElement(
        Description,
        { key: field.Id, term: field.Label },
        '' + (_lodash2['default'].isString(field.Payload.Prefix) ? field.Payload.Prefix + ' ' : '') + data[field.Column] + (_lodash2['default'].isString(field.Payload.Suffix) ? ' ' + field.Payload.Suffix : '')
      ) : null;
    case _InputStyle2['default'].Select:
      var displayFn = function displayFn(val) {
        return (_lodash2['default'].find(field.Payload.Options, function (x) {
          return x.Value === val;
        }) || {}).Display;
      };
      return data[field.Column] && !_lodash2['default'].isEmpty(data[field.Column]) ? _react2['default'].createElement(
        Description,
        { key: field.Id, term: field.Label },
        ['multiple', 'tags'].indexOf(field.Payload.Mode) !== -1 ? _lodash2['default'].map(data[field.Column], function (k) {
          return displayFn(k);
        }).join(', ') : displayFn(data[field.Column])
      ) : null;
    case _InputStyle2['default'].RangePicker:
      return data[field.Column] && _lodash2['default'].isArray(data[field.Column]) ? data[field.Column].length === 2 && data[field.Column][0] && data[field.Column][1] ? _react2['default'].createElement(
        Description,
        { key: field.Id, term: field.Label },
        showDate(data[field.Column][0]),
        ' - ',
        showDate(data[field.Column][1])
      ) : null : null;
    case _InputStyle2['default'].Hidden:
      return null;
    case _InputStyle2['default'].MoneyInput:
      return data[field.Column] ? _react2['default'].createElement(
        Description,
        { key: field.Id, term: field.Label },
        '$' + (0, _numeral2['default'])(data[field.Column]).format('0,0.00')
      ) : null;
    case _InputStyle2['default'].DisplayOnly:
      return data[field.Column] ? _react2['default'].createElement(
        Description,
        { key: field.Id, term: field.Label },
        data[field.Column]
      ) : null;
    default:
      if (showExtra) {
        return showExtra(field, data, showProps);
      }
      throw new Error('FormCore: Unspported input style ' + field.InputStyle + ' of field ' + field.Id + '. You might want to consider using customized input styles, cf. the showExtra parameter. Otheriwse pull Requests are welcome: https://github.com/pmq20/FormCore/pulls');
  }
}